Add a ``leap_second_strict`` argument to the ``Time.to_datetime()`` method. This
controls the behavior when converting a time within a leap second to the ``datetime``
format and can take the values ``raise`` (the default), ``warn``, or ``silent``.
